@@ -3,7 +3,7 @@ package Test::Compile::Internal;
 use warnings;
 use strict;
 
-use version; our $VERSION = qv("v2.0_0");
+use version; our $VERSION = qv("v2.0.1");
 use File::Spec;
 use UNIVERSAL::require;
 use Test::Builder;
@@ -52,7 +52,7 @@ Checks all the perl files it can find for compilation errors.
 
 If C<@dirs> is defined then it is taken as an array of directories to
 be searched for perl files, otherwise it searches some default locations
-- see L</all_pm_files()> and L</all_pl_files()>.
+- see L</all_pm_files(@dirs)> and L</all_pl_files(@dirs)>.
 
 =cut
 sub all_files_ok {
